/**
 * 
 * 语聊室 -- 星钻榜
 */
import React, { Component } from 'react'
import { Tabs } from 'antd-mobile'
import styles from './CoinRanks.less'
import { RankList } from './components'
import { getLotteryRankList } from '@/services/api'
import NativeHook from '@/utils/NativeHook'
import iconBack from '@/assets/icon_back.png'
import router from 'umi/router'
const typeTabList = [
  { title: '星钻', key: 'diamond', unit: '星钻' },
  { title: '星尘', key: 'dust', unit: '星尘' },
]
const tabList = [
  { title: '手气榜', key: 'day' },
  // { title: '周榜', key: 'week' },
  // { title: '月榜', key: 'month' },
]
class CoinRanks extends Component {
  constructor(props) {
    NativeHook.init()
    super(props)
    this.state = {
      lotteryId: props.location.query.lotteryId,
      useList: [],
      currentTypeTab: 'diamond',
      currentTab: 'day'
    }
    this.listMap = new Map()
  }
  componentDidMount() {
    document.title = this.props.route.name
    const { roomId } = this.state
    this.getRanks(roomId)
  }
  // 返回上级页面
  goBack = () => {
    router.goBack()
  }
  getRankList = (list) => {
    const retList = []
    for (let i in list) {
      const item = list[i]
      // 递归找到比自己大的那一项
      let diffAmount = 0
      const prevIndex = this.findItem(Number(item.amount), i, list)
      if (prevIndex > -1) {
        // 计算距上一名的值
        diffAmount = Number(list[prevIndex].amount) - Number(item.amount)
      }
      item.diffAmount = diffAmount
      retList.push(item);
    }
    return retList;
  }
  findItem = (amount, index, list) => {
    if (index > 0) {
      for (let i = index - 1; i < index; i--) {
        if (Number(list[i].amount) > amount) {
          return i
        }
      }
    }
    return -1
  }
  // 获取排行榜列表
  // roomId 为 0 的时候更换接口
  getRanks = async () => {
    const { lotteryId, currentTypeTab, currentTab } = this.state
    const _state = {}
    const mapKey = currentTypeTab + currentTab
    try {
      let result = {}
      switch (mapKey) {
        case 'diamondday':
          result = await getLotteryRankList({ rankType: 1, lotteryId })
          break
        case 'diamondweek':
          result = await getLotteryRankList({ rankType: 2, lotteryId })
          break
        case 'diamondmonth':
          result = await getLotteryRankList({ rankType: 3, lotteryId })
          break
      }

      const { code, data } = result
      if (code === 'OK' && data) {
        const { list } = data;
        let newList = this.getRankList(list);
        const firstMapKey = mapKey + 'first'
        const secondMapKey = mapKey + 'second'
        const thirdMapKey = mapKey + 'third'
        this.listMap.set(firstMapKey, newList.splice(0, 1)[0])
        this.listMap.set(secondMapKey, newList.splice(0, 1)[0])
        this.listMap.set(thirdMapKey, newList.splice(0, 1)[0])
        this.listMap.set(mapKey, newList)
      }
    } catch (e) {
      console.log(e)
    }
    this.setState(_state)
  }


  // 日/周/月
  onTabChange = (modalData) => {
    this.setState({ currentTab: modalData.key }, this.getRanks)
  }
  // 星钻/星尘 tab切换
  // onTypeTabChange = (modalData) => {
  //   this.setState({ currentTypeTab: modalData.key, currentTab: 'day' }, this.getRanks)
  // }
  componentWillUnmount() {
    NativeHook.destroy()
  }
  render() {
    const {
      currentTypeTab,
      currentTab
    } = this.state
    // 从map中取出数据
    const baseKey = currentTypeTab + currentTab
    const useList = this.listMap.get(baseKey)
    const firstMapKey = baseKey + 'first'
    const secondMapKey = baseKey + 'second'
    const thirdMapKey = baseKey + 'third'
    const firstUserInfo = this.listMap.get(firstMapKey)
    const secondUserInfo = this.listMap.get(secondMapKey)
    const thirdUserInfo = this.listMap.get(thirdMapKey)

    // 获取当前tab的计量单位
    const currentTypeTabObj = typeTabList.find(item => item.key === currentTypeTab)
    const currentTypeUnit = currentTypeTabObj ? currentTypeTabObj.unit : ''
    return (
      <div className={styles['wrap']}>
        <div className={styles['content-wrap']}>
          <div className={styles['icon-close']}>
            <img src={iconBack} className={styles['icon-close-img']} onClick={this.goBack} />
          </div>
          <div className={styles['wrap-top-fill']} />
          <Tabs
            tabs={tabList}
            page={currentTab}
            onChange={this.onTabChange}
            swipeable={false}
          >
            {
              tabList.map((item) => (
                <div className={styles['list-wrap']} key={item.key} >
                  <RankList
                    list={useList}
                    currentTypeUnit={currentTypeUnit}
                    firstUserInfo={firstUserInfo}
                    secondUserInfo={secondUserInfo}
                    thirdUserInfo={thirdUserInfo}
                    NativeHook={NativeHook}
                  />
                </div>
              ))
            }
          </Tabs>
        </div>
      </div>
    )
  }
}
export default CoinRanks
