import React, { Component } from 'react'
import styles from './GameTravel.less'
import NativeHook from '@/utils/NativeHook'
import { getLottery, getUserWallet, lottery } from '@/services/api'
import titleGame from './assets/title_game.png'
import { PageWrap, PageFooter, HeaderRecharge } from './components'
import SVGA from 'svgaplayerweb'
import router from 'umi/router'
import { formatBalance, checkRewardType } from '@/utils/base'

class GameTravel extends Component {
  constructor (props) {
    super(props)
    this.state = {
      // 抽奖id
      lotteryId: props.location.query.lotteryId,
      // 是否显示动效
      isShowAnimation: true,
      activityInfo: {}
    }
  }
  componentDidMount () {
    NativeHook.init()
    // 获取抽奖活动详情
    this.getLottery()
    // 初始化动效
    this.lottieInit()
  }
  /**
   * 获取我的余额
   */
  getMyWallet = async (walletType) => {
    const _state = {}
    try {
      const { code, data } = await getUserWallet()
      if (code === 'OK' && data) {
        const { walletItems } = data
        const wallet = walletItems.find(item => item.walletType === walletType)
        _state.walletBalance = wallet ? +wallet.balance : 0
        _state.walletBalanceStr = formatBalance(_state.walletBalance)
      }
    } catch (e) {
      console.log(e)
    }
    this.setState(_state)
  }
  lottieInit = () => {
    const path = '/planet.svga'
    this.player = new SVGA.Player(this.svgaRef);
    this.parser = new SVGA.Parser(this.svgaRef); // 如果你需要支持 IE6+，那么必须把同样的选择器传给 Parser。
    this.parser.load(path, (videoItem) => {
      this.player.setVideoItem(videoItem);
      this.player.startAnimation();
    })
  }
  getLottery = async () => {
    const _state = {}
    try {
      const { lotteryId } = this.state 
      if (!lotteryId) {
        return
      }
      const _params = {
        lotteryId
      }
      const { code, data } = await getLottery(_params)
      if (code === 'OK' && data) {
        const { quantities } = data
        _state.activityInfo = data
        _state.lotteryBtnArray = quantities ? quantities.split(',') : [1, 10, 50]
        if (_state.lotteryBtnArray.length > 3) {
          _state.lotteryBtnArray = _state.lotteryBtnArray.splice(0, 3)
        }
        // 计算
        _state.lotteryBtnArray = _state.lotteryBtnArray.map((item) => ({
          times: item, rewards: item * data.lotteryPrice
        }))
        // 获取我的余额
        this.getMyWallet(data.lotteryPriceType)
      }
    } catch (e) {
      console.log(e)
    }
    this.setState(_state)
  }

  // 进行抽奖
  onLottery = item => async () => {
    if (this.state.uploading) {
      return
    }
    // 计算钱是不是够不够条充值
    const { walletBalance } = this.state
    if (walletBalance < item.rewards) {
      this.goRecharge()
      return
    }
    const _state = { uploading: false }
    try {
      const { lotteryId } = this.state
      this.setState({ uploading: true })
      const { code, data } = await lottery({
        lotteryId, times: item.times
      })
      if (code === 'OK' && data) {
        _state.winRewards = checkRewardType(data.winRewards)
        _state.isShowAnimation = false
        const { activityInfo } = this.state
        this.getMyWallet(activityInfo.lotteryPriceType)
      }
    } catch (e) {
      console.log(e)
    }
    this.setState(_state)
  }

  // 跳转到更多
  goPageMore = () => {
    const { activityInfo } = this.state
    router.push({
      pathname: '/travel/more',
      query: {
        lotteryId: this.state.lotteryId,
        activityId: activityInfo.activityId
      }
    })
  }

  // 充值完成
  goRecharge = () => {
    NativeHook.go.recharge(() => {
      const { activityInfo } = this.state
      // 充值成功 刷新余额
      this.getMyWallet(activityInfo.lotteryPriceType || 11)
    })
  }

  // 关闭页面
  onClosePage = () => {
    NativeHook.call.close()
  }

  componentWillUnmount () {
    NativeHook.destroy()
  }
  render () {
    const { 
      walletBalanceStr, winRewards, isShowAnimation, lotteryBtnArray, uploading 
    } = this.state
    const winRewardsLength = winRewards ? winRewards.length : 0
    return (
      <PageWrap className={styles['wrap']}>
        <div className={styles['header-recharge-wrap']}>
          <HeaderRecharge 
            goPageMore={this.goPageMore}
            goRecharge={this.goRecharge}
            walletBlance={walletBalanceStr}
            onClosePage={this.onClosePage}
          />
        </div>
        <div className={styles['page-content']} >
          <div className={styles['svga-wrap']} hidden={!isShowAnimation} ref={node => this.svgaRef = node} />
          <div className={styles['rewards-wrap']} hidden={isShowAnimation}>
            <div className={styles['rewards-container']}>
              <div className={styles['gift-list']}>
                {
                  winRewards && winRewards.map((item, i) => (
                    <div key={i} className={styles['list-item']}>
                      <div className={styles['img-wrap']}>
                        <img src={item.rewardIcon} alt=""/>
                      </div>
                      <div>
                        <span>x{item.quantity}</span>
                      </div>
                    </div>
                  ))
                }
              </div>
              <div hidden={uploading || winRewardsLength} className={styles['no-win']}>抱歉!您未中奖!</div>
            </div>
          </div>
        </div>
        <PageFooter 
          onLottery={this.onLottery}
          lotteryBtnArray={lotteryBtnArray}
          uploading={uploading}
        />
      </PageWrap>
    )
  }
}
export default GameTravel
