/**
 * 
 * 旅行礼品清单
 */
import React, { Component } from 'react'
import styles from './TravelGiftList.less'
import { PageWrap } from './components'
import titleRules from './assets/title_gifts_list.png'
import iconBack from '@/assets/icon_back.png'
import router from 'umi/router'
import Decimal from 'decimal.js'
import { getRewardItem } from '@/services/api'
import NativeHook from '@/utils/NativeHook'

class TravelGiftList extends Component {
  constructor (props) {
    super(props)
    this.state = {
      lotteryId: props.location.query.lotteryId
    }
  }

  componentDidMount () {
    NativeHook.init()
    this.getRewardItem()
  }

  checkRewardType = (list) => {
    for (let i in list) {
      const item = list[i]
      item.valueStr = item.rewardValue + '星钻/个'
      item.ratioStr = new Decimal(item.ratio).mul(new Decimal(1000)).toNumber() + '‰'
      switch (item.rewardType) {
        case 201:
          item.rewardName = item.rewardId + '星钻'
          break;
        case 202:
          item.rewardName = item.rewardId + '星元'
          break;
        case 211:
          item.rewardName = item.rewardId + '星币'
          break;
        case 301:
          item.rewardName = item.rewardId + '财富值'
          break;
        case 302:
          item.rewardName = item.rewardId + '魅力值'
          break;
  
        default:
          break;
      }
    }
    return list
  }

  getRewardItem = async () => {
    const { lotteryId } = this.state
    if (!lotteryId) {
      return
    }
    try {
      this.setState({ loading: true })
      const { code, data } = await getRewardItem({ lotteryId })
      if (code === 'OK') {
        const { list } = data
        this.setState({
          gifts: this.checkRewardType(list)
        })
      } 
    } catch (e) {
      console.log(e)
    }
    this.setState({ loading: false })
  }

  goBack = () => {
    router.goBack()
  }
  componentWillUnmount () {
    NativeHook.destroy()
  }
  render () {
    const { gifts } = this.state
    return (
      <PageWrap
        header={<img src={titleRules} />}
      >
        <div className={styles['wrap']}>
          <div className={styles['header-wrap']}>
            <img src={iconBack} alt="" onClick={this.goBack} />
          </div>
          <div className={styles['content-box']}>
            <div className={styles['table-wrap']}>
      
              <div className={styles['tr']}>
                <div className={styles['td']}>
                  奖项
                </div>
                <div className={`${styles['td']} center`}>
                  价值
                </div>
                <div className={`${styles['td']} center`}>
                  综合概率
                </div>
              </div>
              {
                gifts && gifts.map((item, i) => (
                  <div className={styles['tr']} key={i}>
                    <div className={styles['td']}>
                      {item.rewardName}
                    </div>
                    <div className={`${styles['td']} center`}>
                      {item.valueStr}
                    </div>
                    <div className={`${styles['td']} center`}>
                      {item.ratioStr}
                    </div>
                  </div>
                ))
              }
              
            </div>
          </div>  
        </div>
      </PageWrap>
    )
  }
}
export default TravelGiftList
