/**
 * 
 * 旅行记录
 */
import React from 'react'
import { PageWrap } from './components'
import styles from './TravelRecords.less'
import iconBack from '@/assets/icon_back.png'
import titleRecords from './assets/title_records.png'
import router from 'umi/router'
import { getActivityRewardList } from '@/services/api'
import NativeHook from '@/utils/NativeHook'
import { getDate } from '@/utils/base'

class TravelRecords extends React.Component {
  constructor (props) {
    super(props)
    this.state = {
      lotteryId: props.location.query.lotteryId,
      activityId: props.location.query.activityId,
      pageIndex: 1,
      loadAll: false,
      list: []
    }
  }
  componentDidMount () {
    NativeHook.init()
    this.getActivityRewardList(1)
  }

  getActivityRewardList = async (pageIndex = 1) => {
    const _state = { loading: false }
    try {
      const { activityId } = this.state 
      if (!activityId) {
        return
      }
      const _params = {
        activityId,
        pageIndex,
        pageSize: 20,
      }
      this.setState({ loading: true })
      const { code, data } = await getActivityRewardList(_params)
      if (code === 'OK' && data) {
        const { list, total, pageSize } = data
        list && list.forEach((item) => {
          item.lotteryTime = item.lotteryTime ? getDate(+item.lotteryTime, 'yyyy.MM.dd hh:mm') : '-'
        })
        _state.list = this.state.list.concat(list)
        _state.total = total
        _state.pageIndex = pageIndex
        _state.pageSize = pageSize
      }
    } catch (e) {
      console.log(e)
    }
    this.setState(_state)
  }

  goBack = () => {
    router.goBack()
  }

  onScroll = (e) => {
    // 外层高度
    const wrapHeight = this.scrollWrapRef.offsetHeight
    // 内容高度
    const containerHeight = this.listContainerRef.offsetHeight
    // 上方滚动的距离
    const scrollTop = this.scrollWrapRef.scrollTop
    // 距离底部的距离
    const dist = containerHeight - wrapHeight - scrollTop
    if (dist <= 400) {
      const { pageIndex, total, pageSize, loading } = this.state
      if (!loading) {
        if (pageIndex * pageSize < total) {
          this.getActivityRewardList(pageIndex + 1)
        } else {
          this.setState({ loadAll: true })
        }
      }
    }
  }

  componentWillUnmount () {
    NativeHook.destroy()
  }
  render () {
    const { list, loadAll } = this.state
    return (
      <PageWrap
        header={<img src={titleRecords} />}
      >
        <div className={styles['wrap']}>
          <div className={styles['header-wrap']}>
            <img src={iconBack} alt="" onClick={this.goBack} />
          </div>
          <div className={styles['list-wrap']} onScroll={this.onScroll} ref={node => this.scrollWrapRef = node}>
            <div ref={node => this.listContainerRef = node}>
              {
                list && list.map((item) => (
                  <div key={item.path} className={styles['list-item']}>
                    <div className={styles['item-info']}>
                      <span>获得</span>
                      <div className={styles['gift-wrap']}>
                        <img src={item.rewardIcon} alt="" className={styles['gift']}/>
                        <span>x{item.quantity}</span>
                      </div>
                    </div>
                    <div className={styles['lottery-time']}>{item.lotteryTime}</div>
                  </div>
                ))
              }
            </div>
          </div>
        </div>
      </PageWrap>
    )
  }
}
export default TravelRecords
