import router from 'umi/router'
import { Base64 as Base64Npm } from 'js-base64'
import { formatMessage } from 'umi-plugin-react/locale'
export const Base64 = Base64Npm

export const pushLocation = (_location) => {
  router.push(_location)
}

// -----------
// ----------- 环境判断类 ----------
// -----------
const USERAGENT = window.navigator.userAgent
//判断微信
export const isWeixin = () => {
  const ua = USERAGENT.toLowerCase();
  const _match = ua.match(/MicroMessenger/i)
  return !!_match && _match[0] === 'micromessenger'
}

// 判断安卓
export const isAndroid = () => {
  return USERAGENT.indexOf('Android') > -1 || USERAGENT.indexOf('Linux') > -1; //g
}
// 判断ios
export const isIos = () => {
  return !!USERAGENT.match(/\(i[^;]+;( U;)? CPU.+Mac OS X/); //ios终端
}
// 判断是否是在 App 中
export const isApp = () => {
  return USERAGENT.indexOf('com.xike.app') > -1
}

// 获取语言
export const getLanguage = () => {
  const reg = /(lang:)([^\/\s])*/ig
  // 英文
  // lang:zh-CN
  let matchArray = USERAGENT.match(reg)
  let first = matchArray ? matchArray[0] : null
  let _lang = first ? first.substr(5) : 'zh-CN'
  if (_lang.indexOf('_') !== -1) {
    // 将下划线转为  中划线
    _lang = _lang.replace('_', '-')
  }
  if (_lang === 'en') {
    _lang = 'en-US'
  }
  return _lang
  // return 'en-US'
}
export const isEnglish = () => {
  return getLanguage() === 'en-US'
  // return true
}

// 获取时间
export const getDate = (nDate = (new Date()), fmt = 'yyyy-MM-dd hh:mm:ss') => {
  const sDate = new Date(nDate)
  const dateObj = {
    'M+': sDate.getMonth() + 1,
    'd+': sDate.getDate(),
    'h+': sDate.getHours(),
    'm+': sDate.getMinutes(),
    's+': sDate.getSeconds(),
    'q+': Math.floor((sDate.getMonth() + 3) / 3),
    'S': sDate.getMilliseconds()
  }
  if (/(y+)/.test(fmt)) {
    fmt = fmt.replace(RegExp.$1, (sDate.getFullYear() + '')
      .substr(4 - RegExp.$1.length))
  }
  for (const s in dateObj) {
    if (new RegExp('(' + s + ')').test(fmt)) {
      fmt = fmt.replace(RegExp.$1, (RegExp.$1.length === 1)
        ? (dateObj[s])
        : (('00' + dateObj[s]).substr(('' + dateObj[s]).length)))
    }
  }
  return fmt
}

// 获取滚动高度
export const getScroll = (win, top) => {
	// window.pageXOffset 
	let ret = win[`page${top ? 'Y' : 'X'}Offset`];
	const method = `scroll${top?'Top':'Left'}`;
	if (typeof ret !== 'number') {
		const d = win.document;
		// documentElement
		ret = d.documentElement[method];
		if (typeof ret !== 'number') {
			// body
			ret = d.body[method];
		}
	}
	return ret;
}

// 整数 正则
export const regIntNumber = /^[1-9]\d*$/

// body 禁止滚动
const preventDefaultFunc = function (e) {
  e.preventDefault()
}
export const setBodyScroll = (isAllow) => {
  const _body = document.body
  if (isAllow) {
    // _body.style.overflow = 'unset' 
    _body.removeEventListener('touchmove', preventDefaultFunc)
    return
  }
  // _body.style.overflow = 'hidden' 
  _body.addEventListener('touchmove', preventDefaultFunc, { passive: false })
}

const ms = 2000
export const showInfoNode = (text, { position } = {}, cb) => {
  var node = document.createElement('div')
  node.className = 'global-show-default'
  if (position === 'bot') {
    node.className = 'global-show-default global-show-bot'
  }
  node.innerText = text
  document.body.appendChild(node)
  var timer = setTimeout(function () {
    clearTimeout(timer)
    document.body.removeChild(node)
    cb && cb()
  }, ms)
}

export const checkRewardType = (list) => {
  for (let i in list) {
    const item = list[i]
    switch (item.rewardType) {
      case 201:
        item.rewardName = item.rewardId + getLocalStr('gems') // '星钻'
        item.rewardIcon = require('@/assets/icon_coin.png')
        break;
      case 202:
        item.rewardName = item.rewardId + getLocalStr('tokens') // '星元'
        item.rewardIcon = require('@/assets/icon_coin.png')
        break;
      case 211:
        item.rewardName = item.rewardId + getLocalStr('coins') // '星币'
        item.rewardIcon = require('@/assets/icon_coin.png')
        break;
      case 301:
        item.rewardName = item.rewardId + getLocalStr('wealth') // '财富值'
        item.rewardIcon = require('@/assets/icon_integral.png')
        break;
      case 302:
        item.rewardName = item.rewardId + getLocalStr('charm') // '魅力值'
        item.rewardIcon = require('@/assets/icon_integral.png')
        break;

      default:
        break;
    }
  }
  return list
}

export const getPriceName = (priceType) => {
  let result = ''
  switch (priceType) {
    case 11:
      result = '星钻'
      break;
    case 12:
      result = '星元'
      break;
    case 21:
      result = '星币'
      break;

    default:
      break;
  }
  return result
}


export const formatBalance = (balance)=>{
  balance = Number(balance)
  if (balance > 9999) {
    balance = parseInt(balance / 1000) / 10 + 'w'
  }
  return balance
}

export const getLocalStr = (id) => {
  if (Array.isArray(id)) {
    return id.map((item) => formatMessage({ id: item }))
  }
  return formatMessage({ id })
}

